#
# spec file for package python-jupyter_qtconsole-doc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} && 0%{?suse_version} != 1315
%bcond_without pdf
%else
%bcond_with pdf
%endif

%bcond_without html

%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-jupyter_qtconsole-doc
Version:        4.3.1
Release:        lp150.2.4
Summary:        Documentation for python-jupyter_qtconsole
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/jupyter/qtconsole
Source:         https://files.pythonhosted.org/packages/source/q/qtconsole/qtconsole-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module jupyter_qtconsole}
%if %{with tests}
# Test requirements
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pexpect}
BuildRequires:  %{python_module qt5}
# Python 2 test requirements
BuildRequires:  python-mock
%endif
# Documentation requirements
%if %{with pdf} || %{with html}
BuildRequires:  python3-Sphinx
%endif
%if %{with pdf}
BuildRequires:  python3-Sphinx-latex
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Provides:       %{name}-html = %{version}
Provides:       %{name}-pdf = %{version}
Obsoletes:      %{name}-html < %{version}
Obsoletes:      %{name}-pdf < %{version}
Provides:       %{python_module jupyter_qtconsole-doc = %{version}}

%description
Documentation and help files for python-jupyter_qtconsole.

%prep
%setup -q -n qtconsole-%{version}
sed -i 's/python3/python/' docs/Makefile

%build
# Build the documentation
pushd docs
%if %{with html}
make html
rm -rf build/html/.buildinfo
%endif
%if %{with pdf}
make latexpdf
%endif
popd

%install
mkdir -p %{buildroot}%{_docdir}/python-jupyter_qtconsole

%if %{with pdf}
cp docs/build/latex/*.pdf %{buildroot}%{_docdir}/python-jupyter_qtconsole/
%endif

%if %{with html}
cp -r docs/build/html %{buildroot}%{_docdir}/python-jupyter_qtconsole/
%endif

cp -r examples %{buildroot}%{_docdir}/python-jupyter_qtconsole/
%fdupes %{buildroot}%{_docdir}/python-jupyter_qtconsole/

%if %{with tests}
%check
%python_expand nosetests-%{$python_bin_suffix}
%endif

%files
%defattr(-,root,root,-)
%doc COPYING.md
%{_docdir}/python-jupyter_qtconsole/

%changelog
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 4.3.1
  * Make %%clear to delete previous output on Windows.
  * Fix SVG rendering.
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 4.3
  + Additions
  * Add :kbd:`Shift-Tab` shortcut to unindent text
  * Add :kbd:`Control-R` shortcut to rename the current tab
  * Add :kbd:`Alt-R` shortcut to set the main window title
  * Add :kbd:`Command-Alt-Left` and :kbd:`Command-Alt-Right` shortcut to switch
    tabs on macOS
  * Add support for PySide2
  * Add support for Python 3.5
  * Add support for 24 bit ANSI color codes
  * Add option to create new tab connected to the existing kernel
  + Changes
  * Change :kbd:`Tab` key behavior to always indent to the next increment of 4 spaces
  * Change :kbd:`Home` key behavior to alternate cursor between the beginning of text
    (ignoring leading spaces) and beginning of the line
  * Improve documentation of various options and clarified the docs in some places
  * Move documentation to ReadTheDocs
  * Rename `ConsoleWidget.width/height` traits to `console_width/console_height`
    to avoid a name clash with the `QWidget` properties. Note: the name change
    could be, in rare cases if a name collision exists, a code-breaking
    change.
  + Fixes
  * Fix automatic indentation of new lines that are inserted in the middle of a
    cell
  * Fix regression where prompt would never be shown for `--existing` consoles
  * Fix `python.exe -m qtconsole` on Windows
  * Fix showing error messages when running a script using `%%run`
  * Fix `invalid cursor position` error and subsequent freezing of user input
  * Fix syntax coloring when attaching to non-IPython kernels
  * Fix printing when using QT5
  * Fix :kbd:`Control-K` shortcut (delete until end of line) on macOS
  * Fix history browsing (:kbd:`Up`/:kbd:`Down` keys) when lines are longer than
    the terminal width
  * Fix saving HTML with inline PNG for Python 3
  * Various internal bugfixes
- Update to 4.2
  * various latex display fixes
  * improvements for embedding in Qt applications (use existing Qt API if one is already loaded)
* Thu Feb 18 2016 toddrme2178@gmail.com
- update to version 4.1.1:
  * Set AppUserModelID for Windows 7 and later
  * Switch to using qtconsole module to find qt
  * Fix Travis tests for Python 2
  * Updated example for creating inprocess qtconsole
  * Enable 3.5 on travis
- Split documentation into subpackage
* Fri Oct 16 2015 toddrme2178@gmail.com
- Update to 4.1.0
  * Fixed generating the default configuration
  * Fixed some regressions in copy/paste from the console.
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Fri Aug 21 2015 toddrme2178@gmail.com
- Remove duplicate requirements
* Thu Aug 13 2015 toddrme2178@gmail.com
- Initial version
